@@ -6,7 +6,7 @@ NewExerciseWindow::NewExerciseWindow(QWidget *parent) :
     QMainWindow(parent)
 {
     setAttribute(Qt::WA_Maemo5StackedWindow);
-    setAttribute(Qt::WA_Maemo5PortraitOrientation);
+    //setAttribute(Qt::WA_Maemo5LandscapeOrientation);
     setWindowTitle("New exercise");
     xml = new XML();
 
@@ -92,6 +92,7 @@ void NewExerciseWindow::load()
     txtHowTo->setText("How to...");
 }
 
+
 void NewExerciseWindow::load(QString name, QString group, QString muscle, QString info)
 {
     txtName->setEnabled(false);
