@@ -599,10 +599,10 @@ void XML::saveCardio(QString name)
    return;
 }
 
-void XML::saveEatenFood(QString kcal)
+void XML::saveEatenFood(QString kcal, QString protein, QString carbohydrate, QString fat)
 {
     QDate date = QDate::currentDate();
-    QString dateString = date.toString("ddMMyy");
+    QString dateString = date.toString("dd-MM-yyyy");
 
     QDomDocument doc( "Calories" );
     QFile file( "/home/user/MyDocs/calories.xml" );
@@ -619,7 +619,7 @@ void XML::saveEatenFood(QString kcal)
     file.remove();
     file.close();
 
-    root.appendChild(createCaloriesNode(doc, kcal, dateString));
+    root.appendChild(createCaloriesNode(doc, kcal, protein, carbohydrate, fat, dateString));
 
     if(!file.open(QIODevice::WriteOnly))
         return ;
@@ -632,19 +632,20 @@ void XML::saveEatenFood(QString kcal)
     return ;
 }
 
-int XML::getTodaysCalories()
+QList <int> XML::getTodaysCalories()
 {
+    QList <int> list;
     QDate date = QDate::currentDate();
-    QString dateString = date.toString("ddMMyy");
+    QString dateString = date.toString("dd-MM-yyyy");
 
     QString tmp;
-    int kcal = 0;
+    int kcal = 0, protein = 0, carbohydrate = 0, fat = 0;
 
     QDomDocument doc( "Calories" );
     QFile file( "/home/user/MyDocs/calories.xml" );
     if( !file.open( QIODevice::ReadOnly ) )
     {
-      return 0;
+      return list;
     }
 
     doc.setContent(&file);
@@ -653,7 +654,7 @@ int XML::getTodaysCalories()
     QDomElement root = doc.documentElement();
     if( root.tagName() != "calorie" )
     {
-      return 0;
+      return list;
     }
 
     QDomNode n = root.firstChild();
@@ -668,12 +669,27 @@ int XML::getTodaysCalories()
             {
                 tmp = e.attribute("kcal", "");
                 kcal += tmp.toInt();
+
+                tmp = e.attribute("protein", "");
+                protein += tmp.toInt();
+
+                tmp = e.attribute("carbohydrate", "");
+                carbohydrate += tmp.toInt();
+
+                tmp = e.attribute("fat", "");
+                fat += tmp.toInt();
             }
         }
       }
       n = n.nextSibling();
    }
-    return kcal;
+
+    list.append(kcal);
+    list.append(protein);
+    list.append(carbohydrate);
+    list.append(fat);
+
+    return list;
 
 }
 
@@ -682,27 +698,28 @@ void XML::getMeanCalories()
 
 }
 
-int XML::getCaloriesByName(QString name)
+QList <int> XML::getCaloriesByName(QString name)
 {
+    QList <int> list;
     QString readInfo;
 
     QDomDocument doc( "Ingredients" );
     QFile file( "/home/user/MyDocs/ingredients.xml" );
 
     if( !file.open( QIODevice::ReadOnly ) )
-      return 0;
+      return list;
 
 
     if( !doc.setContent( &file ) )
     {
       file.close();
-      return 0;
+      return list;
     }
     file.close();
 
     QDomElement root = doc.documentElement();
     if( root.tagName() != "ingredient" )
-      return 0;
+      return list;
 
 
     QDomNode n = root.firstChild();
@@ -716,23 +733,29 @@ int XML::getCaloriesByName(QString name)
             if(name == e.attribute( "name", "" ))
             {
                 readInfo = e.attribute("kcal", "");
-                return readInfo.toInt();
+                list.append(readInfo.toInt());
+                readInfo = e.attribute("protein", "");
+                list.append(readInfo.toInt());
+                readInfo = e.attribute("carbohydrate", "");
+                list.append(readInfo.toInt());
+                readInfo = e.attribute("fat", "");
+                list.append(readInfo.toInt());
+                return list;
             }
         }
       }
       n = n.nextSibling();
    }
-    return readInfo.toInt();
+    return list;
 }
 
-void XML::saveFood(QString name, QString type, QString kcal)
+void XML::saveFood(QString name, QString type, QString kcal, QString protein, QString carbohydrate, QString fat)
 {
 
     QDomDocument doc( "Ingredients" );
     QFile file( "/home/user/MyDocs/ingredients.xml" );
     file.open( QIODevice::ReadOnly );
     doc.setContent( &file );
-    file.remove();
     file.close();
 
     //leta efter en vning med samma namn, isf ta bort den
@@ -759,8 +782,10 @@ void XML::saveFood(QString name, QString type, QString kcal)
    ts << doc.toString();
 
    doc.clear();
-   file.open( QIODevice::ReadOnly );
+
+   file.open( QIODevice::ReadWrite );
    doc.setContent( &file );
+   file.remove();
 
    root = doc.documentElement();
    if( root.tagName() != "ingredient" )
@@ -770,7 +795,7 @@ void XML::saveFood(QString name, QString type, QString kcal)
    }
    file.close();
 
-   root.appendChild(createFoodNode(doc, name, type, kcal));
+   root.appendChild(createFoodNode(doc, name, type, kcal, protein, carbohydrate, fat));
 
    if(!file.open(QIODevice::WriteOnly))
        return;
@@ -918,24 +943,30 @@ QDomElement XML::createCardioNode( QDomDocument &d, QString name)
    return cn;
 }
 
-QDomElement XML::createCaloriesNode( QDomDocument &d, QString kcal, QString date)
+QDomElement XML::createCaloriesNode( QDomDocument &d, QString kcal, QString protein, QString carbohydrate, QString fat, QString date)
 {
    QDomElement cn = d.createElement( "calorie" );
 
    cn.setAttribute( "kcal", kcal );
+   cn.setAttribute( "protein", protein );
+   cn.setAttribute( "carbohydrate", carbohydrate );
+   cn.setAttribute( "fat", fat );
    cn.setAttribute( "date", date );
 
 
    return cn;
 }
 
-QDomElement XML::createFoodNode( QDomDocument &d, QString name, QString type, QString kcal)
+QDomElement XML::createFoodNode( QDomDocument &d, QString name, QString type, QString kcal, QString protein, QString carbohydrate, QString fat)
 {
    QDomElement cn = d.createElement( "ingredient" );
 
    cn.setAttribute( "name", name );
    cn.setAttribute( "type", type );
    cn.setAttribute( "kcal", kcal );
+   cn.setAttribute( "protein", protein );
+   cn.setAttribute( "carbohydrate", carbohydrate );
+   cn.setAttribute( "fat", fat );
 
    return cn;
 }
